{ *********************************************************** }
{ HotPDF PDF Component                                        }
{ Copyright(c)2007-2018, https://www.loslab.com               }
{ *********************************************************** }
{$APPTYPE CONSOLE}
{$I ..\HotPDF.inc}

Program TableDemo;
{ Reduce EXE size by disabling as much of RTTI as possible }
{$IFDEF D2010+}
{$WEAKLINKRTTI ON}
{$RTTI EXPLICIT METHODS([]) PROPERTIES([]) FIELDS([])}
{$ENDIF}

Uses
  {$IFDEF XE2+}
  System.Classes,
  System.SysUtils,
  Vcl.Graphics,
  WinAPI.ActiveX,
  //Data.DB,
  Data.Win.ADODB,
  {$ELSE} 
  Classes,
  SysUtils,
  Graphics,
  ActiveX,
  DB,
  ADODB,
  {$ENDIF} 
  HPDFDoc;

Var
  HotPDF: THotPDF;
  PageNum, VertPos: Integer;
  Table: TADOTable;
  Back: boolean;

Procedure PrintRow(Position: Integer; No, Company, Addr, City: AnsiString; ShowBackground: boolean);
Begin
  If ShowBackground
  Then
  Begin
    HotPDF.CurrentPage.SetRGBColor($fff3dd);
    HotPDF.CurrentPage.Rectangle(50, Position, 520, 20);
    HotPDF.CurrentPage.Fill;
    HotPDF.CurrentPage.SetRGBColor(clBlack);
  End;
  HotPDF.CurrentPage.TextOut(70, Position, 0, No);
  HotPDF.CurrentPage.TextOut(110, Position, 0, Company);
  HotPDF.CurrentPage.TextOut(300, Position, 0, Addr);
  HotPDF.CurrentPage.TextOut(480, Position, 0, City);
End;

Procedure PreparePage;
Begin
  HotPDF.CurrentPage.SetFont('Arial', [fsItalic], 10);
  HotPDF.CurrentPage.TextOut(50, VertPos, 0, 'customer.db' + '  Page' + AnsiString(IntToStr(PageNum)));
  HotPDF.CurrentPage.TextOut(480, VertPos, 0, AnsiString(DateTimeToStr(Now)));
  HotPDF.CurrentPage.MoveTo(50, VertPos + 15);
  HotPDF.CurrentPage.LineTo(570, VertPos + 15);
  HotPDF.CurrentPage.MoveTo(50, VertPos + 45);
  HotPDF.CurrentPage.LineTo(570, VertPos + 45);
  HotPDF.CurrentPage.Stroke;
  HotPDF.CurrentPage.SetFont('Times New Roman', [fsItalic, fsBold], 12);
  HotPDF.CurrentPage.SetRGBFillColor(clNavy);
  PrintRow(VertPos + 25, 'No', 'Company', 'Addr', 'City', false);
  HotPDF.CurrentPage.SetRGBFillColor(clBlack);
  Inc(VertPos, 20);
End;

Begin
  Try
    CoInitialize(nil);
    Table := TADOTable.Create(Nil);
    Table.ConnectionString := 'Provider=Microsoft.Jet.OLEDB.4.0;' + 'Data Source=Customer.mdb;' +
      'Mode=Read;' + 'Persist Security Info=False';
    Table.TableName := 'Customer';
    Table.Active := True;
    HotPDF := THotPDF.Create(Nil);
    Try
      HotPDF.AutoLaunch := True;
      HotPDF.FileName := 'TableDemo.pdf';
      HotPDF.PageLayout := plOneColumn;
      HotPDF.BeginDoc;
      HotPDF.CurrentPage.SetFont('Arial', [fsBold], 24);
      HotPDF.CurrentPage.TextOut(200, 20, 0, 'Customer report'); // Print PDF header
      PageNum := 1;
      VertPos := 60;
      PreparePage; // Table header
      Back := True;
      Table.First;
      While (Not(Table.Recordset.EOF)) Do
      Begin
        Back := Not(Back);
        If (VertPos > 700)
        Then // If end of page then
        Begin
          HotPDF.AddPage; // Add page, draw and print
          Inc(PageNum);   // table header and set
          VertPos := 60;  // new print position
          PreparePage;
        End;
        PrintRow(VertPos + 25, // print row from the current position
          AnsiString(Table.FieldValues['CustNo']), AnsiString(Table.FieldValues['Company']),
          AnsiString(Table.FieldValues['Addr1']), AnsiString(Table.FieldValues['City']), Back);
        Inc(VertPos, 20);
        Table.Next;
      End;
      HotPDF.EndDoc;
    Finally
      HotPDF.Free;
    End;
  Finally
    Table.Free;
    CoUninitialize;
  End;
End.
